- n:        普通名词
- nd:        方位名词
- nh:        人名
- ni:        机构名
- nl:        处所名词
- ns:        地名
- nt:        时间词
- nz:        其他专名

- a:        形容词
- b:        区别词
- c:        连词
- d:        副词
- e:        叹词
- g:        语素字
- h:        前接成分
- i:        习用语
- j:        简称
- k:        后接成分
- m:        数词
- o:        拟声词
- p:        介词
- q:        量词
- r:        代词
- u:        助词
- v:        动词
- wp:        标点符号
- ws:        字符串
- x:        非语素字